==> com.liferay.analytics.settings.rest.impl-1.0.13-sources-commercial.jar: com/liferay/analytics/settings/rest/internal/resource/v1_0/FieldSummaryResourceImpl.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.analytics.settings.rest.internal.resource.v1_0;

import com.liferay.analytics.settings.configuration.AnalyticsConfiguration;
import com.liferay.analytics.settings.rest.dto.v1_0.FieldSummary;
import com.liferay.analytics.settings.rest.manager.AnalyticsSettingsManager;
import com.liferay.analytics.settings.rest.resource.v1_0.FieldSummaryResource;

import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;
import org.osgi.service.component.annotations.ServiceScope;

/**
 * @author Riccardo Ferrari
 */
@Component(
	properties = "OSGI-INF/liferay/rest/v1_0/field-summary.properties",
	scope = ServiceScope.PROTOTYPE, service = FieldSummaryResource.class
)
public class FieldSummaryResourceImpl extends BaseFieldSummaryResourceImpl {

	@Override
	public FieldSummary getField() throws Exception {
		AnalyticsConfiguration analyticsConfiguration =
			_analyticsSettingsManager.getAnalyticsConfiguration(
				contextCompany.getCompanyId());

		String[] syncedAccountFieldNames =
			analyticsConfiguration.syncedAccountFieldNames();
		String[] syncedCategoryFieldNames =
			analyticsConfiguration.syncedCategoryFieldNames();
		String[] syncedContactFieldNames =
			analyticsConfiguration.syncedContactFieldNames();
		String[] syncedOrderFieldNames =
			analyticsConfiguration.syncedOrderFieldNames();
		String[] syncedProductFieldNames =
			analyticsConfiguration.syncedProductFieldNames();
		String[] syncedProductChannelFieldNames =
			analyticsConfiguration.syncedProductChannelFieldNames();
		String[] syncedUserFieldNames =
			analyticsConfiguration.syncedUserFieldNames();

		return new FieldSummary() {
			{
				account = syncedAccountFieldNames.length;
				order = syncedOrderFieldNames.length;
				people =
					syncedContactFieldNames.length +
						syncedUserFieldNames.length;
				product =
					syncedCategoryFieldNames.length +
						syncedProductFieldNames.length +
							syncedProductChannelFieldNames.length;
			}
		};
	}

	@Reference
	private AnalyticsSettingsManager _analyticsSettingsManager;

}

==> com.liferay.analytics.settings.rest.impl-1.0.14-sources-commercial.jar: com/liferay/analytics/settings/rest/internal/resource/v1_0/FieldSummaryResourceImpl.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.analytics.settings.rest.internal.resource.v1_0;

import com.liferay.analytics.settings.configuration.AnalyticsConfiguration;
import com.liferay.analytics.settings.rest.dto.v1_0.FieldSummary;
import com.liferay.analytics.settings.rest.manager.AnalyticsSettingsManager;
import com.liferay.analytics.settings.rest.resource.v1_0.FieldSummaryResource;

import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;
import org.osgi.service.component.annotations.ServiceScope;

/**
 * @author Riccardo Ferrari
 */
@Component(
	properties = "OSGI-INF/liferay/rest/v1_0/field-summary.properties",
	scope = ServiceScope.PROTOTYPE, service = FieldSummaryResource.class
)
public class FieldSummaryResourceImpl extends BaseFieldSummaryResourceImpl {

	@Override
	public FieldSummary getField() throws Exception {
		AnalyticsConfiguration analyticsConfiguration =
			_analyticsSettingsManager.getAnalyticsConfiguration(
				contextCompany.getCompanyId());

		String[] syncedAccountFieldNames =
			analyticsConfiguration.syncedAccountFieldNames();
		String[] syncedCategoryFieldNames =
			analyticsConfiguration.syncedCategoryFieldNames();
		String[] syncedContactFieldNames =
			analyticsConfiguration.syncedContactFieldNames();
		String[] syncedOrderFieldNames =
			analyticsConfiguration.syncedOrderFieldNames();
		String[] syncedOrderItemFieldNames =
			analyticsConfiguration.syncedOrderItemFieldNames();
		String[] syncedProductFieldNames =
			analyticsConfiguration.syncedProductFieldNames();
		String[] syncedProductChannelFieldNames =
			analyticsConfiguration.syncedProductChannelFieldNames();
		String[] syncedUserFieldNames =
			analyticsConfiguration.syncedUserFieldNames();

		return new FieldSummary() {
			{
				account = syncedAccountFieldNames.length;
				order =
					syncedOrderFieldNames.length +
						syncedOrderItemFieldNames.length;
				people =
					syncedContactFieldNames.length +
						syncedUserFieldNames.length;
				product =
					syncedCategoryFieldNames.length +
						syncedProductFieldNames.length +
							syncedProductChannelFieldNames.length;
			}
		};
	}

	@Reference
	private AnalyticsSettingsManager _analyticsSettingsManager;

}
